@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -332,15 +332,12 @@ class FlexTemplatesServiceClient(metaclass=FlexTemplatesServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def launch_flex_template(
         self,
-        request: templates.LaunchFlexTemplateRequest = None,
+        request: Union[templates.LaunchFlexTemplateRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -349,7 +346,7 @@ class FlexTemplatesServiceClient(metaclass=FlexTemplatesServiceClientMeta):
         r"""Launch a job with a FlexTemplate.
 
         Args:
-            request (google.cloud.dataflow_v1beta3.types.LaunchFlexTemplateRequest):
+            request (Union[google.cloud.dataflow_v1beta3.types.LaunchFlexTemplateRequest, dict]):
                 The request object. A request to launch a Cloud Dataflow
                 job from a FlexTemplate.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -382,6 +379,19 @@ class FlexTemplatesServiceClient(metaclass=FlexTemplatesServiceClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
