@@ -428,5 +428,8 @@ class JobsV1Beta3GrpcTransport(JobsV1Beta3Transport):
             )
         return self._stubs["snapshot_job"]
 
+    def close(self):
+        self.grpc_channel.close()
+
 
 __all__ = ("JobsV1Beta3GrpcTransport",)
