@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -330,15 +330,12 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def list_job_messages(
         self,
-        request: messages.ListJobMessagesRequest = None,
+        request: Union[messages.ListJobMessagesRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -355,7 +352,7 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
         ``us-central1``.
 
         Args:
-            request (google.cloud.dataflow_v1beta3.types.ListJobMessagesRequest):
+            request (Union[google.cloud.dataflow_v1beta3.types.ListJobMessagesRequest, dict]):
                 The request object. Request to list job messages.
                 Up to max_results messages will be returned in the time
                 range specified starting with the oldest messages first.
@@ -400,6 +397,19 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
