@@ -327,5 +327,8 @@ class MetricsV1Beta3GrpcAsyncIOTransport(MetricsV1Beta3Transport):
             )
         return self._stubs["get_stage_execution_details"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("MetricsV1Beta3GrpcAsyncIOTransport",)
