@@ -311,5 +311,8 @@ class SnapshotsV1Beta3GrpcAsyncIOTransport(SnapshotsV1Beta3Transport):
             )
         return self._stubs["list_snapshots"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("SnapshotsV1Beta3GrpcAsyncIOTransport",)
