@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -333,15 +333,12 @@ class TemplatesServiceClient(metaclass=TemplatesServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def create_job_from_template(
         self,
-        request: templates.CreateJobFromTemplateRequest = None,
+        request: Union[templates.CreateJobFromTemplateRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -350,7 +347,7 @@ class TemplatesServiceClient(metaclass=TemplatesServiceClientMeta):
         r"""Creates a Cloud Dataflow job from a template.
 
         Args:
-            request (google.cloud.dataflow_v1beta3.types.CreateJobFromTemplateRequest):
+            request (Union[google.cloud.dataflow_v1beta3.types.CreateJobFromTemplateRequest, dict]):
                 The request object. A request to create a Cloud Dataflow
                 job from a template.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -385,7 +382,7 @@ class TemplatesServiceClient(metaclass=TemplatesServiceClientMeta):
 
     def launch_template(
         self,
-        request: templates.LaunchTemplateRequest = None,
+        request: Union[templates.LaunchTemplateRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -394,7 +391,7 @@ class TemplatesServiceClient(metaclass=TemplatesServiceClientMeta):
         r"""Launch a template.
 
         Args:
-            request (google.cloud.dataflow_v1beta3.types.LaunchTemplateRequest):
+            request (Union[google.cloud.dataflow_v1beta3.types.LaunchTemplateRequest, dict]):
                 The request object. A request to launch a template.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -428,7 +425,7 @@ class TemplatesServiceClient(metaclass=TemplatesServiceClientMeta):
 
     def get_template(
         self,
-        request: templates.GetTemplateRequest = None,
+        request: Union[templates.GetTemplateRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -437,7 +434,7 @@ class TemplatesServiceClient(metaclass=TemplatesServiceClientMeta):
         r"""Get the template associated with a template.
 
         Args:
-            request (google.cloud.dataflow_v1beta3.types.GetTemplateRequest):
+            request (Union[google.cloud.dataflow_v1beta3.types.GetTemplateRequest, dict]):
                 The request object. A request to retrieve a Cloud
                 Dataflow job template.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -470,6 +467,19 @@ class TemplatesServiceClient(metaclass=TemplatesServiceClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
